==> kbilliards-0.7.tar.bz2: kbilliards-0.7/src/samuele.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Samuele Catuzzi                                 *
 *   samuele_catuzzi@yahoo.it                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef SAMUELEMATH_H
#define SAMUELEMATH_H

#include <math.h>

namespace samuele {

/**
@author Samuele Catuzzi
*/
class Vector{
public:
    Vector();
    Vector(double,double,double);
    ~Vector();
    
    Vector operator+(Vector );  // sum
    Vector operator-(Vector );  // minus
    double operator*(Vector );  // product
    
    Vector operator*(double );  // vector*scalar
    
    Vector unit();  // vector unit
    double abs();   // |vector|
    void   null();  // vector 0
    
    static Vector projection( Vector, Vector ); // projection
public:
    double x;
    double y;
    double z;        
};


};

#endif

==> kbilliards-0.8.7b.tar.bz2: kbilliards-0.8.7b/src/samuele.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Samuele Catuzzi                                 *
 *   samuele_catuzzi@yahoo.it                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef SAMUELEMATH_H
#define SAMUELEMATH_H

#include <math.h>

namespace samuele {

/**
@author Samuele Catuzzi
*/
class Vector{
public:
    Vector();
    Vector(double,double,double);
    Vector(double,double);
    ~Vector();

    Vector operator+(Vector );  // sum
    Vector operator-(Vector );  // minus
    double operator*(Vector );  // |U||V|cos(alpha) (scalar product of vectors)

    Vector operator*(double );  // vector*scalar

    Vector unit();  // vector unit
    double abs();   // |vector|
    void   null();  // vector 0

    void set(double x,double y,double z); //set values
    static Vector projection( Vector, Vector ); // projection
public:
    double x;
    double y;
    double z;
};


};

#endif
